@@ -1,6 +1,7 @@
 """Implement kaibu-utils."""
 import io
 
+import requests
 import numpy as np
 from geojson import Feature, FeatureCollection
 from geojson import Polygon as geojson_polygon
@@ -20,6 +21,8 @@ from skimage.morphology import remove_small_objects
 
 try:
     import pyodide
+    import pyodide_http
+    pyodide_http.patch_all()  # Patch all libraries
 
     is_pyodide = True
 except ImportError:
@@ -401,19 +404,14 @@ def mask_to_features(img_mask, label=None, mask_type="labels"):
 
 
 async def fetch_image(url, name=None, grayscale=False, transpose=False, size=None):
-    if is_pyodide:
-        from js import fetch
-
-        response = await fetch(url)
-        bytes = await response.arrayBuffer()
-        bytes = bytes.to_py()
-        buffer = io.BytesIO(bytes)
+    response = requests.get(url)
+    buffer = io.BytesIO(response.content)
+    if "//zenodo.org/api/" in url:
+        default_name = url.split("?")[0].split("/")[-2]
     else:
-        import requests
-
-        response = requests.get(url)
-        buffer = io.BytesIO(response.content)
-    buffer.name = name or url.split("?")[0].split("/")[1]
+        default_name = url.split("?")[0].split("/")[-1]
+        
+    buffer.name = name or default_name
     image = Image.open(buffer)
     if grayscale:
         image = image.convert("L")
